@@ -1,12 +1,14 @@
 var group__libssh__string =
 [
     [ "ssh_string_burn", "group__libssh__string.html#gaca1c58e13e7bdb72ea8410592fa0cbf6", null ],
+    [ "ssh_string_cmp", "group__libssh__string.html#ga2cdcc3ef237f8aa5349b21001c04e41f", null ],
     [ "ssh_string_copy", "group__libssh__string.html#ga566a98997af205210ed6c24fc5a5cb21", null ],
     [ "ssh_string_data", "group__libssh__string.html#ga977147eebd08ad0619aa6de6218927e7", null ],
     [ "ssh_string_fill", "group__libssh__string.html#gad5626768334f4837c4a31e5b4a68d130", null ],
     [ "ssh_string_free", "group__libssh__string.html#gacd9c4eb69f7ecfdcf709deb8dde6a5a8", null ],
     [ "ssh_string_free_char", "group__libssh__string.html#gafc10700722d6cafc468c2ee97585449a", null ],
     [ "ssh_string_from_char", "group__libssh__string.html#ga3f4e397885369927a66840626e217137", null ],
+    [ "ssh_string_from_data", "group__libssh__string.html#ga431c5c636d8481ec4c4bd22654415cde", null ],
     [ "ssh_string_get_char", "group__libssh__string.html#gada306ef3f18485ea75041d85a43e2175", null ],
     [ "ssh_string_len", "group__libssh__string.html#ga331553369afbfcb4f5300729ed65d0fe", null ],
     [ "ssh_string_new", "group__libssh__string.html#ga47182accf343c50830a9d05b7dfa83b5", null ],
