@@ -42,19 +42,10 @@ var NAVTREE =
       [ "Static Linking", "libssh_linking.html#static", null ]
     ] ],
     [ "The Tutorial", "libssh_tutorial.html", "libssh_tutorial" ],
+    [ "API Reference", "topics.html", "topics" ],
     [ "Install a FreeBSD CI instance", "md_README_8gitlab_8freebsd.html", null ],
     [ "Bug List", "bug.html", null ],
     [ "Deprecated List", "deprecated.html", null ],
-    [ "Topics", "topics.html", "topics" ],
-    [ "Data Structures", "annotated.html", [
-      [ "Data Structures", "annotated.html", "annotated_dup" ],
-      [ "Data Structure Index", "classes.html", null ],
-      [ "Data Fields", "functions.html", [
-        [ "All", "functions.html", null ],
-        [ "Functions", "functions_func.html", null ],
-        [ "Variables", "functions_vars.html", null ]
-      ] ]
-    ] ],
     [ "Files", "files.html", [
       [ "File List", "files.html", "files_dup" ]
     ] ]
@@ -64,8 +55,8 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "agent_8h_source.html",
-"group__libssh__pki.html#ga78c1f26eac4345a56749b4e086d9fa28",
-"group__libssh__string.html#gacd9c4eb69f7ecfdcf709deb8dde6a5a8"
+"group__libssh__poll.html#ga26c19b17ac8d1e3d7fcbfb4367fb93ff",
+"group__libssh__sftp.html#gad01f42405d742709739ad708277004c3"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
