@@ -6,6 +6,8 @@ var searchData=
   ['be_20done_3',['To be done',['../libssh_tutor_todo.html',1,'libssh_tutorial']]],
   ['buffer_20functions_4',['The SSH buffer functions',['../group__libssh__buffer.html',1,'']]],
   ['bug_20list_5',['Bug List',['../bug.html',1,'']]],
-  ['by_20the_20remote_20computer_6',['Displaying the data sent by the remote computer',['../libssh_tutor_shell.html#read_data',1,'']]],
-  ['by_20the_20sftp_20aio_20api_7',['Capping applied by the sftp aio API',['../libssh_tutor_sftp_aio.html#sftp_aio_cap',1,'']]]
+  ['building_20with_20fido2_20support_6',['Building with FIDO2 Support',['../libssh_tutor_fido2.html#fido2_build',1,'']]],
+  ['burn_5ffree_7',['burn_free',['../group__libssh__misc.html#ga6d309fe557efff160bebbd466ddea8da',1,'burn_free(void *ptr, size_t len):&#160;misc.c'],['../group__libssh__misc.html#ga6d309fe557efff160bebbd466ddea8da',1,'burn_free(void *ptr, size_t len):&#160;misc.c']]],
+  ['by_20the_20remote_20computer_8',['Displaying the data sent by the remote computer',['../libssh_tutor_shell.html#read_data',1,'']]],
+  ['by_20the_20sftp_20aio_20api_9',['Capping applied by the sftp aio API',['../libssh_tutor_sftp_aio.html#sftp_aio_cap',1,'']]]
 ];
