@@ -1,13 +1,13 @@
 var indexSectionsWithContent =
 {
-  0: "0123456789:abcdefghiklmnoprstuwxy",
-  1: "cs",
-  2: "acdegilosuw",
-  3: "acdefgilmsu",
+  0: "0123456789:abcdefghiklmnoprstuvwxy",
+  1: "clmst",
+  2: "abcdegilopsuw",
+  3: "acdefgiklmnprsuv",
   4: "s",
   5: "s",
   6: "abcefhiklmpstw",
-  7: "0123456789:abcdefghiklmnoprstuwxy"
+  7: "0123456789:abcdefghiklmnoprstuvwxy"
 };
 
 var indexSectionNames =
