@@ -9,5 +9,6 @@ var searchData=
   ['f_5fflag_6',['f_flag',['../structsftp__statvfs__struct.html#abcc2c48299b8cec7715105e757a0e9a9',1,'sftp_statvfs_struct']]],
   ['f_5ffrsize_7',['f_frsize',['../structsftp__statvfs__struct.html#adb890a7fb6ee008fd246ebe93c5f3c64',1,'sftp_statvfs_struct']]],
   ['f_5ffsid_8',['f_fsid',['../structsftp__statvfs__struct.html#aefd16d855b51182773a8239f106c7709',1,'sftp_statvfs_struct']]],
-  ['f_5fnamemax_9',['f_namemax',['../structsftp__statvfs__struct.html#a8e094d2dbb5e8686e8c3f7b20b14e1c9',1,'sftp_statvfs_struct']]]
+  ['f_5fnamemax_9',['f_namemax',['../structsftp__statvfs__struct.html#a8e094d2dbb5e8686e8c3f7b20b14e1c9',1,'sftp_statvfs_struct']]],
+  ['flags_10',['flags',['../structsk__enroll__response.html#a8c8325c8a79de5b5e33aa06bedb8f817',1,'sk_enroll_response::flags'],['../structsk__sign__response.html#a55cf8d175388b3178fdf51582a8cb0d3',1,'sk_sign_response::flags'],['../structsk__resident__key.html#a21dfbe51295624f91bd61e6375fb3511',1,'sk_resident_key::flags']]]
 ];
