@@ -2,5 +2,6 @@ var searchData=
 [
   ['global_5frequest_5ffunction_0',['global_request_function',['../structssh__callbacks__struct.html#affa000c51d64fb6bb10c1ab7109ab1f1',1,'ssh_callbacks_struct']]],
   ['gssapi_5faccept_5fsec_5fctx_5ffunction_1',['gssapi_accept_sec_ctx_function',['../structssh__server__callbacks__struct.html#a14030ebc1ed211eb66ba513812729db3',1,'ssh_server_callbacks_struct']]],
-  ['gssapi_5fselect_5foid_5ffunction_2',['gssapi_select_oid_function',['../structssh__server__callbacks__struct.html#aecc399daa70f5595d6e921f58f93e7f0',1,'ssh_server_callbacks_struct']]]
+  ['gssapi_5fselect_5foid_5ffunction_2',['gssapi_select_oid_function',['../structssh__server__callbacks__struct.html#aecc399daa70f5595d6e921f58f93e7f0',1,'ssh_server_callbacks_struct']]],
+  ['gssapi_5fverify_5fmic_5ffunction_3',['gssapi_verify_mic_function',['../structssh__server__callbacks__struct.html#a271c182e9599871b35a3dec984b6df47',1,'ssh_server_callbacks_struct']]]
 ];
